History
==========

0.0.3 (2021-05-24)
------------------

* renamed classes and removed Minos prefix
* Integration of Command and CommandReply with Handler

0.0.4 (2021-05-31)
------------------

* Documentation improvement
* BugFixes

0.0.5 (2021-05-31)
------------------

* BugFixes

0.0.6 (2021-06-02)
------------------

* Added Retry functionality at Broker
* Added Locked status at Broker
* Bugfix

0.0.7 (2021-07-06)
------------------

* Added basic approach for Circuit Braker ( Broker and Publisher)
* SQL queries refactor ( added support for psycopg method for query building )
* Migration of shapshot to Minos Common
* Updated Test
* BugFix
* Added clients for Minos Discovery Service
* Added support for Docker and Docker-Compose

0.0.8 (2021-07-12)
------------------

* Add new version support for minos-common
* BugFix

0.0.9 (2021-07-12)
------------------

* BugFix
